# DRS4

[![Release](https://img.shields.io/pypi/v/drs4?label=Release&color=cornflowerblue&style=flat-square)](https://pypi.org/project/drs4/)
[![Python](https://img.shields.io/pypi/pyversions/drs4?label=Python&color=cornflowerblue&style=flat-square)](https://pypi.org/project/drs4/)
[![Downloads](https://img.shields.io/pypi/dm/drs4?label=Downloads&color=cornflowerblue&style=flat-square)](https://pepy.tech/project/drs4)
[![DOI](https://img.shields.io/badge/DOI-10.5281/zenodo.18709559-cornflowerblue?style=flat-square)](https://doi.org/10.5281/zenodo.18709559)
[![Tests](https://img.shields.io/github/actions/workflow/status/finerreceiver/drs4/tests.yaml?label=Tests&style=flat-square)](https://github.com/finerreceiver/drs4/actions)

Control and data acquisition software for FINER/DRS4

## Installation

```python
pip install drs4
```
